@@ -3,6 +3,7 @@
 """
 """
 
+from rest_framework.fields import is_simple_callable
 from rest_framework.serializers import Field
 
 
@@ -19,8 +20,13 @@ class ModelPermissionsField(Field):
         data = ''
         try:
             attr = getattr(obj, self.field or field_name)
+
+            if is_simple_callable(getattr(attr, 'all', None)):
+                attr = attr.all()
+
+            many = hasattr(attr, '__iter__') and not isinstance(attr, dict)
             context = {'request': self.context.get('request')}
-            serialized = self.serializer(attr, context=context)
+            serialized = self.serializer(attr, context=context, many=many)
             data = serialized.data
         except AttributeError:
             pass
